==> mdapy-0.10.6-cp39-cp39-win_amd64.whl: mdapy/__init__.py <==
# Copyright (c) 2022-2024, mushroomfire in Beijing Institute of Technology
# This file is from the mdapy project, released under the BSD 3-Clause License.


# start delvewheel patch
def _delvewheel_patch_1_5_2():
    import ctypes
    import os
    import platform
    import sys
    libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, '.'))
    is_conda_cpython = platform.python_implementation() == 'CPython' and (hasattr(ctypes.pythonapi, 'Anaconda_GetVersion') or 'packaged by conda-forge' in sys.version)
    if sys.version_info[:2] >= (3, 8) and not is_conda_cpython or sys.version_info[:2] >= (3, 10):
        if os.path.isdir(libs_dir):
            os.add_dll_directory(libs_dir)
    else:
        load_order_filepath = os.path.join(libs_dir, '.load-order-mdapy-0.10.6')
        if os.path.isfile(load_order_filepath):
            with open(os.path.join(libs_dir, '.load-order-mdapy-0.10.6')) as file:
                load_order = file.read().split()
            for lib in load_order:
                lib_path = os.path.join(os.path.join(libs_dir, lib))
                kernel32 = ctypes.WinDLL('kernel32', use_last_error=True)
                if os.path.isfile(lib_path) and not kernel32.LoadLibraryExW(ctypes.c_wchar_p(lib_path), None, 0x00000008):
                    raise OSError('Error loading {}; {}'.format(lib, ctypes.FormatError(ctypes.get_last_error())))


_delvewheel_patch_1_5_2()
del _delvewheel_patch_1_5_2
# end delvewheel patch

__author__ = "mushroomfire aka HerrWu"
__version__ = "0.10.6"
__license__ = "BSD License"

from .main import main
from .ackland_jones_analysis import AcklandJonesAnalysis
from .centro_symmetry_parameter import CentroSymmetryParameter
from .cluser_analysis import ClusterAnalysis
from .common_neighbor_analysis import CommonNeighborAnalysis
from .common_neighbor_parameter import CommonNeighborParameter
from .create_polycrystalline import CreatePolycrystalline
from .dft2nepxyz import DFT2NEPXYZ, LabeledSystem
from .eam_average import EAMAverage
from .eam_generate import EAMGenerate
from .entropy import AtomicEntropy
from .identify_SFs_TBs import IdentifySFTBinFCC
from .nearest_neighbor import NearestNeighbor
from .lattice_maker import LatticeMaker
from .lindemann_parameter import LindemannParameter
from .mean_squared_displacement import MeanSquaredDisplacement
from .neighbor import Neighbor
from .pair_distribution import PairDistribution
from .plotset import pltset, pltset_old, cm2inch, set_figure
from .polyhedral_template_matching import PolyhedralTemplateMatching
from .potential import EAM, NEP
from .phonon import Phonon
from .perturb_model import PerturbModel
from .spatial_binning import SpatialBinning
from .steinhardt_bond_orientation import SteinhardtBondOrientation
from .system import System, MultiSystem
from .temperature import AtomicTemperature
from .tool_function import split_dump, split_xyz, timer
from .void_distribution import VoidDistribution
from .voronoi_analysis import VoronoiAnalysis
from .warren_cowley_parameter import WarrenCowleyParameter
from .replicate import Replicate
from .pigz import compress_file
from .tool_function import atomic_numbers, vdw_radii, atomic_masses

import os

os.environ["KMP_DUPLICATE_LIB_OK"] = "TRUE"


def init(
    arch="cpu",
    cpu_max_num_threads=-1,
    offline_cache=False,
    debug=False,
    device_memory_fraction=0.9,
    kernel_profiler=False,
):
    """Initilize the mdapy calculation. One should call this function after import mdapy.
    This is a simple wrapper function of `taichi.init() <https://docs.taichi-lang.org/api/taichi/#taichi.init>`_.

    Args:
        arch (str, optional): run on CPU or GPU. Defaults to "cpu", choose in 'cpu' and 'gpu'.

        cpu_max_num_threads (int, optional): maximum CPU core to use in calculation. Defaults to -1, indicating using all available CPU cores.

        offline_cache (bool, optional): whether save compile cache. Defaults to False.

        debug (bool, optional): whether use debug mode. Defaults to False.

        device_memory_fraction (float, optional): preallocate available GPU memory fraction. Defaults to 90%.

        kernel_profiler (bool, optional): whether enable profiler. Defaults to False.

    Raises:
        ValueError: Unrecognized arch, please choose in ['cpu', 'gpu'].
    """
    import taichi as ti

    if arch == "cpu":
        if cpu_max_num_threads == -1:
            ti.init(
                arch=ti.cpu,
                offline_cache=offline_cache,
                debug=debug,
                kernel_profiler=kernel_profiler,
                default_fp=ti.f64,
            )
        else:
            ti.init(
                arch=ti.cpu,
                cpu_max_num_threads=cpu_max_num_threads,
                offline_cache=offline_cache,
                debug=debug,
                kernel_profiler=kernel_profiler,
                default_fp=ti.f64,
            )
    elif arch == "gpu":
        ti.init(
            arch=ti.gpu,
            offline_cache=offline_cache,
            device_memory_fraction=device_memory_fraction,
            debug=debug,
            kernel_profiler=kernel_profiler,
            default_fp=ti.f64,
        )
    else:
        raise ValueError("Unrecognized arch, please choose in ['cpu', 'gpu'].")

==> mdapy-0.11.2-cp39-cp39-win_amd64.whl: mdapy/__init__.py <==
# Copyright (c) 2022-2024, mushroomfire in Beijing Institute of Technology
# This file is from the mdapy project, released under the BSD 3-Clause License.


# start delvewheel patch
def _delvewheel_patch_1_5_2():
    import ctypes
    import os
    import platform
    import sys
    libs_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, '.'))
    is_conda_cpython = platform.python_implementation() == 'CPython' and (hasattr(ctypes.pythonapi, 'Anaconda_GetVersion') or 'packaged by conda-forge' in sys.version)
    if sys.version_info[:2] >= (3, 8) and not is_conda_cpython or sys.version_info[:2] >= (3, 10):
        if os.path.isdir(libs_dir):
            os.add_dll_directory(libs_dir)
    else:
        load_order_filepath = os.path.join(libs_dir, '.load-order-mdapy-0.11.2')
        if os.path.isfile(load_order_filepath):
            with open(os.path.join(libs_dir, '.load-order-mdapy-0.11.2')) as file:
                load_order = file.read().split()
            for lib in load_order:
                lib_path = os.path.join(os.path.join(libs_dir, lib))
                kernel32 = ctypes.WinDLL('kernel32', use_last_error=True)
                if os.path.isfile(lib_path) and not kernel32.LoadLibraryExW(ctypes.c_wchar_p(lib_path), None, 0x00000008):
                    raise OSError('Error loading {}; {}'.format(lib, ctypes.FormatError(ctypes.get_last_error())))


_delvewheel_patch_1_5_2()
del _delvewheel_patch_1_5_2
# end delvewheel patch

__author__ = "mushroomfire aka HerrWu"
__version__ = "0.11.2"
__license__ = "BSD License"

from .main import main
from .ackland_jones_analysis import AcklandJonesAnalysis
from .bond_analysis import BondAnalysis
from .centro_symmetry_parameter import CentroSymmetryParameter
from .cluser_analysis import ClusterAnalysis
from .common_neighbor_analysis import CommonNeighborAnalysis
from .common_neighbor_parameter import CommonNeighborParameter
from .create_polycrystalline import CreatePolycrystalline
from .dft2nepxyz import DFT2NEPXYZ, LabeledSystem
from .eam_average import EAMAverage
from .eam_generate import EAMGenerate
from .entropy import AtomicEntropy
from .identify_SFs_TBs import IdentifySFTBinFCC
from .nearest_neighbor import NearestNeighbor
from .lattice_maker import LatticeMaker
from .lindemann_parameter import LindemannParameter
from .minimizer import Minimizer
from .mean_squared_displacement import MeanSquaredDisplacement
from .neighbor import Neighbor
from .orthogonal_box import OrthogonalBox
from .pair_distribution import PairDistribution
from .plotset import pltset, pltset_old, cm2inch, set_figure
from .polyhedral_template_matching import PolyhedralTemplateMatching
from .potential import EAM, NEP, BasePotential
from .perturb_model import PerturbModel
from .spatial_binning import SpatialBinning
from .steinhardt_bond_orientation import SteinhardtBondOrientation
from .system import System, MultiSystem
from .temperature import AtomicTemperature
from .tool_function import split_dump, split_xyz, timer
from .void_distribution import VoidDistribution
from .voronoi_analysis import VoronoiAnalysis
from .warren_cowley_parameter import WarrenCowleyParameter
from .replicate import Replicate
from .pigz import compress_file
from .tool_function import atomic_numbers, vdw_radii, atomic_masses

import os

os.environ["KMP_DUPLICATE_LIB_OK"] = "TRUE"


def init(
    arch="cpu",
    cpu_max_num_threads=-1,
    offline_cache=False,
    debug=False,
    device_memory_fraction=0.9,
    kernel_profiler=False,
):
    """Initilize the mdapy calculation. One should call this function after import mdapy.
    This is a simple wrapper function of `taichi.init() <https://docs.taichi-lang.org/api/taichi/#taichi.init>`_.

    Args:
        arch (str, optional): run on CPU or GPU. Defaults to "cpu", choose in 'cpu' and 'gpu'.

        cpu_max_num_threads (int, optional): maximum CPU core to use in calculation. Defaults to -1, indicating using all available CPU cores.

        offline_cache (bool, optional): whether save compile cache. Defaults to False.

        debug (bool, optional): whether use debug mode. Defaults to False.

        device_memory_fraction (float, optional): preallocate available GPU memory fraction. Defaults to 90%.

        kernel_profiler (bool, optional): whether enable profiler. Defaults to False.

    Raises:
        ValueError: Unrecognized arch, please choose in ['cpu', 'gpu'].
    """
    import taichi as ti

    if arch == "cpu":
        if cpu_max_num_threads == -1:
            ti.init(
                arch=ti.cpu,
                offline_cache=offline_cache,
                debug=debug,
                kernel_profiler=kernel_profiler,
                default_fp=ti.f64,
            )
        else:
            ti.init(
                arch=ti.cpu,
                cpu_max_num_threads=cpu_max_num_threads,
                offline_cache=offline_cache,
                debug=debug,
                kernel_profiler=kernel_profiler,
                default_fp=ti.f64,
            )
    elif arch == "gpu":
        ti.init(
            arch=ti.gpu,
            offline_cache=offline_cache,
            device_memory_fraction=device_memory_fraction,
            debug=debug,
            kernel_profiler=kernel_profiler,
            default_fp=ti.f64,
        )
    else:
        raise ValueError("Unrecognized arch, please choose in ['cpu', 'gpu'].")
